/* 
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
var idioma_espanol = {
    "sProcessing": "Procesando...",
    "sLengthMenu": "Mostrar _MENU_ registros",
    "sZeroRecords": "No se encontraron resultados",
    "sEmptyTable": "Ningún dato disponible en esta tabla",
    "sInfo": "Mostrando registros del _START_ al _END_ de un total de _TOTAL_ registros",
    "sInfoEmpty": "Mostrando registros del 0 al 0 de un total de 0 registros",
    "sInfoFiltered": "(filtrado de un total de _MAX_ registros)",
    "sInfoPostFix": "",
    "sSearch": "Buscar:",
    "sUrl": "",
    "sInfoThousands": ",",
    "sLoadingRecords": "Cargando...",
    "oPaginate": {
        "sFirst": "Primero",
        "sLast": "Último",
        "sNext": "Siguiente",
        "sPrevious": "Anterior"
    },
    "oAria": {
        "sSortAscending": ": Activar para ordenar la columna de manera ascendente",
        "sSortDescending": ": Activar para ordenar la columna de manera descendente"
    }
}

function dibujarSelectForm(id, asId, asDes, data) {
    document.getElementById(id).innerHTML = "";
    if (!isEmpty(data)) {
        $('#' + id).append('<option value="" disabled selected>Seleccionar</option>');
        $.each(data, function (index, item) {
            $('#' + id).append('<option value="' + item[asId] + '">' + item[asDes] + '</option>');
        });
    }
    $('#' + id).formSelect();
}

function dibujarSelect2Form(id, asId, asDes, data) {
    document.getElementById(id).innerHTML = "";
    if (!isEmpty(data)) {
        $.each(data, function (index, item) {
            $('#' + id).append('<option value="' + item[asId] + '">' + item[asDes] + '</option>');
        });
    }
    $('#' + id).formSelect();
}

function dibujarSelect2(id, asId, asDes, data) {
    document.getElementById(id).innerHTML = "";
    if (!isEmpty(data)) {
        $('#' + id).append('<option value="">Todos</option>');
        $.each(data, function (index, item) {
            $('#' + id).append('<option value="' + item[asId] + '">' + item[asDes] + '</option>');
        });
    }
    asignarValorSelect2(id, 0);
}

function asignarValorSelect2(id, valor) {
    $("#" + id).val(valor).trigger('change');
}

function asignarValorSelectFrom(id, valor) {
    $('#' + id).val(valor);
    $('#' + id).formSelect();
}

function asignarValorDatepicker(id, fecha) {
    var queryDate = null;
    if (!isEmpty(fecha)) {
        var fechaFormato = convertDateFormatAsignar(fecha);
        var queryDate = new Date(fechaFormato);
    }
    $('#' + id).datepicker('setDate', queryDate);
    $('#' + id).siblings('label').addClass('active');
    $('#' + id).val(fecha);
}

function convertDateFormatAsignar(fecha) {
    var info = fecha.split('/').reverse().join('/');
    return info;
}

function formatoFechaMostrar(valor) {
    if (valor == '0000-00-00 00:00:00') {
        return "-";
    } else {
        if (isEmpty(valor))
            return '';
        var ss = (valor.split('-'));
        var d = parseInt(ss[2], 10);
        if (isEmpty(d) || d > 31 || d < 1)
            return "";
        var m = parseInt(ss[1], 10);
        if (isEmpty(m) || m > 12 || m < 1)
            return "";
        var y = parseInt(ss[0], 10);
        if (isEmpty(y) || y > 9999 || y < 1000)
            return "";

        return (d < 10 ? ('0' + d) : d) + '/' + (m < 10 ? ('0' + m) : m) + '/' + y;
    }
}


function testAnim(x) {
    $('#cardAlert').removeClass().addClass(x + ' animated').one('webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend', function () {
        $(this).removeClass();
    });
}

function mostrarAlerta(mensaje, tipo) {
    var alerta = '<div id="divAlert" class="fixed-action-btn direction-left" style="bottom: 550px;">'
            + '<div id="cardAlert" >'
            + '<div class="card-alert card ' + tipo + ' floating">'
            + '<div class="card-content white-text">'
            + '<p>' + mensaje + '</p>'
            + '</div></div></div></div>';
    $('#divMostrarAlerta').html(alerta);
    testAnim('bounceInRight');
    $('#divMostrarAlerta').show();

    setTimeout(function () {
        $('#divMostrarAlerta').hide();
        $('#divMostrarAlerta').html('');
    }, 3000);
}

function cargarDiv(url)
{
    $("#main").html("");
    $("#main").load(url);
}

function isEmpty(value)
{
    if ($.type(value) === 'undefined')
        return true;
    if ($.type(value) === 'null')
        return true;
    if ($.type(value) === 'string' && value.length <= 0)
        return true;
    if ($.type(value) === 'array' && value.length === 0)
        return true;
    if ($.type(value) === 'number' && isNaN(parseInt(value)))
        return true;

    return false;
}

